AllOrSome

Enum AllOrSome 

pub enum AllOrSome<T> {
    All,
    Some(T),
}
An enum signifying that some of type T is allowed, or All (anything is allowed).

Variants



All

Everything is allowed. Usually equivalent to the * value.



Some(T)

Only some of T is allowed

Implementations

Source

impl<T> AllOrSome<T>

pub fn is_all(&self) -> bool

Returns whether this is an All variant.

pub fn is_some(&self) -> bool

Returns whether this is a Some variant.

pub fn as_ref(&self) -> Option<&T>

Provides a shared reference to T if variant is Some.

pub fn as_mut(&mut self) -> Option<&mut T>

Provides a mutable reference to T if variant is Some.